# io.swagger.client - Kotlin client library for App Weather - A Weather Source API

## Requires

* Kotlin 1.1.2
* Gradle 3.3

## Build

First, create the gradle wrapper script:

```
gradle wrapper
```

Then, run:

```
./gradlew check assemble
```

This runs all tests and packages the library.

## Features/Implementation Notes

* Supports JSON inputs/outputs, File inputs, and Form inputs.
* Supports collection formats for query parameters: csv, tsv, ssv, pipes.
* Some Kotlin and Java types are fully qualified to avoid conflicts with types defined in Swagger definitions.
* Implementation of ApiClient is intended to reduce method counts, specifically to benefit Android targets.

<a name="documentation-for-api-endpoints"></a>
## Documentation for API Endpoints

All URIs are relative to *https://appwx.weathersourceapis.com/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*OnpointsApi* | [**onpointsOnpointIdGet**](docs/OnpointsApi.md#onpointsonpointidget) | **GET** /onpoints/{onpointId} | App Weather for an OnPoint™ point.
*PointsApi* | [**pointsLatitudelongitudeGet**](docs/PointsApi.md#pointslatitudelongitudeget) | **GET** /points/{latitude},{longitude} | App Weather for a Latitude/Longitude point.
*PostcodesApi* | [**postcodesPostcodecountryCodeGet**](docs/PostcodesApi.md#postcodespostcodecountrycodeget) | **GET** /postcodes/{postcode},{countryCode} | App Weather response for a postcode.

<a name="documentation-for-models"></a>
## Documentation for Models

 - [io.swagger.client.models.AppwxOnpointObj](docs/AppwxOnpointObj.md)
 - [io.swagger.client.models.AppwxPointObj](docs/AppwxPointObj.md)
 - [io.swagger.client.models.AppwxPostcodeObj](docs/AppwxPostcodeObj.md)
 - [io.swagger.client.models.BoundingPoints](docs/BoundingPoints.md)
 - [io.swagger.client.models.BoundingPointsInner](docs/BoundingPointsInner.md)
 - [io.swagger.client.models.CivilRise](docs/CivilRise.md)
 - [io.swagger.client.models.CivilSet](docs/CivilSet.md)
 - [io.swagger.client.models.CldCvr](docs/CldCvr.md)
 - [io.swagger.client.models.CldCvrMax](docs/CldCvrMax.md)
 - [io.swagger.client.models.CldCvrMin](docs/CldCvrMin.md)
 - [io.swagger.client.models.CountryCode](docs/CountryCode.md)
 - [io.swagger.client.models.CountryName](docs/CountryName.md)
 - [io.swagger.client.models.Date](docs/Date.md)
 - [io.swagger.client.models.Distance](docs/Distance.md)
 - [io.swagger.client.models.Elevation](docs/Elevation.md)
 - [io.swagger.client.models.ErrorObj](docs/ErrorObj.md)
 - [io.swagger.client.models.FeaturesObj](docs/FeaturesObj.md)
 - [io.swagger.client.models.FeelsLike](docs/FeelsLike.md)
 - [io.swagger.client.models.FeelsLikeMax](docs/FeelsLikeMax.md)
 - [io.swagger.client.models.FeelsLikeMin](docs/FeelsLikeMin.md)
 - [io.swagger.client.models.FieldListObj](docs/FieldListObj.md)
 - [io.swagger.client.models.Fields](docs/Fields.md)
 - [io.swagger.client.models.ForecastDayArr](docs/ForecastDayArr.md)
 - [io.swagger.client.models.ForecastDayObj](docs/ForecastDayObj.md)
 - [io.swagger.client.models.ForecastHourArr](docs/ForecastHourArr.md)
 - [io.swagger.client.models.ForecastHourObj](docs/ForecastHourObj.md)
 - [io.swagger.client.models.Grid](docs/Grid.md)
 - [io.swagger.client.models.Icon](docs/Icon.md)
 - [io.swagger.client.models.Language](docs/Language.md)
 - [io.swagger.client.models.Latitude](docs/Latitude.md)
 - [io.swagger.client.models.Longitude](docs/Longitude.md)
 - [io.swagger.client.models.MoonPhase](docs/MoonPhase.md)
 - [io.swagger.client.models.NowcastObj](docs/NowcastObj.md)
 - [io.swagger.client.models.OnpointId](docs/OnpointId.md)
 - [io.swagger.client.models.OnpointObj](docs/OnpointObj.md)
 - [io.swagger.client.models.PointObj](docs/PointObj.md)
 - [io.swagger.client.models.Postcode](docs/Postcode.md)
 - [io.swagger.client.models.PostcodeObj](docs/PostcodeObj.md)
 - [io.swagger.client.models.Precip](docs/Precip.md)
 - [io.swagger.client.models.PrecipFlag](docs/PrecipFlag.md)
 - [io.swagger.client.models.PrecipIntensity](docs/PrecipIntensity.md)
 - [io.swagger.client.models.PrecipProb](docs/PrecipProb.md)
 - [io.swagger.client.models.RelHum](docs/RelHum.md)
 - [io.swagger.client.models.RelHumMax](docs/RelHumMax.md)
 - [io.swagger.client.models.RelHumMin](docs/RelHumMin.md)
 - [io.swagger.client.models.Snowfall](docs/Snowfall.md)
 - [io.swagger.client.models.SnowfallFlag](docs/SnowfallFlag.md)
 - [io.swagger.client.models.SnowfallIntensity](docs/SnowfallIntensity.md)
 - [io.swagger.client.models.SnowfallProb](docs/SnowfallProb.md)
 - [io.swagger.client.models.SubdivCode](docs/SubdivCode.md)
 - [io.swagger.client.models.SubdivName](docs/SubdivName.md)
 - [io.swagger.client.models.Summary](docs/Summary.md)
 - [io.swagger.client.models.SummaryLong](docs/SummaryLong.md)
 - [io.swagger.client.models.SunTransit](docs/SunTransit.md)
 - [io.swagger.client.models.Sunrise](docs/Sunrise.md)
 - [io.swagger.client.models.Sunset](docs/Sunset.md)
 - [io.swagger.client.models.Temp](docs/Temp.md)
 - [io.swagger.client.models.TempMax](docs/TempMax.md)
 - [io.swagger.client.models.TempMin](docs/TempMin.md)
 - [io.swagger.client.models.Timestamp](docs/Timestamp.md)
 - [io.swagger.client.models.Timezone](docs/Timezone.md)
 - [io.swagger.client.models.UnitScale](docs/UnitScale.md)
 - [io.swagger.client.models.WindDir](docs/WindDir.md)
 - [io.swagger.client.models.WindDirAvg](docs/WindDirAvg.md)
 - [io.swagger.client.models.WindSpd](docs/WindSpd.md)
 - [io.swagger.client.models.WindSpdMax](docs/WindSpdMax.md)
 - [io.swagger.client.models.WindSpdMin](docs/WindSpdMin.md)

<a name="documentation-for-authorization"></a>
## Documentation for Authorization

<a name="ApiKeyAuth"></a>
### ApiKeyAuth


