# PostcodesApi

All URIs are relative to *https://appwx.weathersourceapis.com/v2*

Method | HTTP request | Description
------------- | ------------- | -------------
[**postcodesPostcodecountryCodeGet**](PostcodesApi.md#postcodesPostcodecountryCodeGet) | **GET** /postcodes/{postcode},{countryCode} | App Weather response for a postcode.

<a name="postcodesPostcodecountryCodeGet"></a>
# **postcodesPostcodecountryCodeGet**
> AppwxPostcodeObj postcodesPostcodecountryCodeGet(postcode, countryCode, services, fields, unitScale, language)

App Weather response for a postcode.

Returns select nowcast and forecast (7-day - daily and hourly) data for a postcode.  The weather icon classes returned by this API correspond to classes used by the open source licensed [Weather Icons](https://developer.weathersourceapis.com/apis/appwx-weather-icons/) font set.  **IMPORTANT:** To authenticate to the Weather Source App Weather API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 

### Example
```kotlin
// Import classes:
//import io.swagger.client.infrastructure.*
//import io.swagger.client.models.*;

val apiInstance = PostcodesApi()
val postcode : kotlin.String = postcode_example // kotlin.String | A postcode string.
val countryCode : kotlin.String = countryCode_example // kotlin.String | An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
val services : kotlin.Array<kotlin.String> =  // kotlin.Array<kotlin.String> | A comma separated list of service names to return.  **Limiting the query to needed services will improve the query response time.** 
val fields : kotlin.Array<kotlin.String> =  // kotlin.Array<kotlin.String> | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.** 
val unitScale : kotlin.String = unitScale_example // kotlin.String | The unit scale for returned values.<br>
val language : kotlin.String = language_example // kotlin.String | The language for translatable returned values.<br>
try {
    val result : AppwxPostcodeObj = apiInstance.postcodesPostcodecountryCodeGet(postcode, countryCode, services, fields, unitScale, language)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling PostcodesApi#postcodesPostcodecountryCodeGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling PostcodesApi#postcodesPostcodecountryCodeGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **postcode** | **kotlin.String**| A postcode string. |
 **countryCode** | **kotlin.String**| An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/). |
 **services** | [**kotlin.Array&lt;kotlin.String&gt;**](kotlin.String.md)| A comma separated list of service names to return.  **Limiting the query to needed services will improve the query response time.**  | [enum: forecastDay, forecastHour, nowcast, all]
 **fields** | [**kotlin.Array&lt;kotlin.String&gt;**](kotlin.String.md)| A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  | [enum: all, allAstronomy, allCldCvr, allFeelsLike, allIcon, allPrecip, allRelHum, allSummary, allTemp, allWind]
 **unitScale** | **kotlin.String**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL] [enum: IMPERIAL, METRIC, SI]
 **language** | **kotlin.String**| The language for translatable returned values.&lt;br&gt; | [optional] [default to ENGLISH] [enum: ENGLISH, FRENCH, SPANISH]

### Return type

[**AppwxPostcodeObj**](AppwxPostcodeObj.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

